pygeodesy.namedTuples.LatLonPrec3Tuple

Package pygeodesy :: Module namedTuples :: Class LatLonPrec3Tuple |
[frames] | no frames]

# Class LatLonPrec3Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       LatLonPrec3Tuple

Known Subclasses:
  - LatLonPrec5Tuple

3-Tuple `(lat, lon, precision)` in `degrees`, `degrees` and `int`.

Instance Methods
to5Tuple(self, height, radius, **name) Extend this LatLonPrec3Tuple to a LatLonPrec5Tuple. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### to5Tuple (self, height, radius, **name) |
Extend this LatLonPrec3Tuple to a LatLonPrec5Tuple. Arguments: `height` - The height to add (`float` or `None`). `radius` - The radius to add (`float` or `None`). `name` - Optional `name=NN` (`str`), overriding this name. Returns: A LatLonPrec5Tuple`(lat, lon, precision, height, radius)`.